# ⚠️ (DEPRECATED) This package has been deprecated ⚠️

The functionality of the toolkits has been incoporated to the new and improved Boulder Opal client, `boulderopal`. Support for the legacy `boulderopaltoolkits` package ended on 2024-01-31. You can read the [Boulder Opal get started guide](https://docs.q-ctrl.com/boulder-opal/get-started) or [contact us](https://q-ctrl.com/contact) if you need assistance.

# Boulder Opal Toolkits

The Boulder Opal Toolkits provide convenience nodes, classes, and functions that simplify the development in Boulder Opal. These toolkits enable you to develop and implement workflows faster and with less code, for a particular physical system or system-agnostic tasks.
